@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # yamllint documentation build configuration file, created by
 # sphinx-quickstart on Thu Jan 21 21:18:52 2016.
 
@@ -21,7 +20,7 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 project = APP_NAME
-copyright = __copyright__
+copyright = __copyright__.lstrip('Copyright ')
 
 version = APP_VERSION
 release = APP_VERSION
@@ -39,7 +38,7 @@ htmlhelp_basename = 'yamllintdoc'
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
 man_pages = [
-    ('index', 'yamllint', '', [u'Adrien Vergé'], 1)
+    ('index', 'yamllint', 'Linter for YAML files', [u'Adrien Vergé'], 1)
 ]
 
 # -- Build with sphinx automodule without needing to install third-party libs
