@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016 Adrien Vergé
 #
 # This program is free software: you can redistribute it and/or modify
@@ -85,19 +84,47 @@ class Format(object):
             line += '  \033[2m(%s)\033[0m' % problem.rule
         return line
 
+    @staticmethod
+    def github(problem, filename):
+        line = '::'
+        line += problem.level
+        line += ' file=' + filename + ','
+        line += 'line=' + format(problem.line) + ','
+        line += 'col=' + format(problem.column)
+        line += '::'
+        line += format(problem.line)
+        line += ':'
+        line += format(problem.column)
+        line += ' '
+        if problem.rule:
+            line += '[' + problem.rule + '] '
+        line += problem.desc
+        return line
+
 
 def show_problems(problems, file, args_format, no_warn):
     max_level = 0
     first = True
 
+    if args_format == 'auto':
+        if ('GITHUB_ACTIONS' in os.environ and
+                'GITHUB_WORKFLOW' in os.environ):
+            args_format = 'github'
+        elif supports_color():
+            args_format = 'colored'
+
     for problem in problems:
         max_level = max(max_level, PROBLEM_LEVELS[problem.level])
         if no_warn and (problem.level != 'error'):
             continue
         if args_format == 'parsable':
             print(Format.parsable(problem, file))
-        elif args_format == 'colored' or \
-                (args_format == 'auto' and supports_color()):
+        elif args_format == 'github':
+            if first:
+                print('::group::%s' % file)
+                first = False
+            print(Format.github(problem, file))
+        elif args_format == 'colored':
             if first:
                 print('\033[4m%s\033[0m' % file)
                 first = False
@@ -108,6 +135,9 @@ def show_problems(problems, file, args_format, no_warn):
                 first = False
             print(Format.standard(problem, file))
 
+    if not first and args_format == 'github':
+        print('::endgroup::')
+
     if not first and args_format != 'parsable':
         print('')
 
@@ -131,7 +161,8 @@ def run(argv=None):
                               action='store',
                               help='custom configuration (as YAML source)')
     parser.add_argument('-f', '--format',
-                        choices=('parsable', 'standard', 'colored', 'auto'),
+                        choices=('parsable', 'standard', 'colored', 'github',
+                                 'auto'),
                         default='auto', help='format for parsing output')
     parser.add_argument('-s', '--strict',
                         action='store_true',
@@ -176,7 +207,8 @@ def run(argv=None):
         print(e, file=sys.stderr)
         sys.exit(-1)
 
-    locale.setlocale(locale.LC_ALL, conf.locale)
+    if conf.locale is not None:
+        locale.setlocale(locale.LC_ALL, conf.locale)
 
     max_level = 0
 
