@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2016 Adrien Vergé
 #
 # This program is free software: you can redistribute it and/or modify
@@ -32,6 +31,16 @@ Use this rule to control the indentation.
 * ``check-multi-line-strings`` defines whether to lint indentation in
   multi-line strings. Set to ``true`` to enable, ``false`` to disable.
 
+.. rubric:: Default values (when enabled)
+
+.. code-block:: yaml
+
+ rules:
+   indentation:
+     spaces: consistent
+     indent-sequences: true
+     check-multi-line-strings: false
+
 .. rubric:: Examples
 
 #. With ``indentation: {spaces: 1}``
@@ -193,7 +202,7 @@ Use this rule to control the indentation.
 import yaml
 
 from yamllint.linter import LintProblem
-from yamllint.rules.common import is_explicit_key, get_real_end_line
+from yamllint.rules.common import get_real_end_line, is_explicit_key
 
 
 ID = 'indentation'
@@ -201,6 +210,9 @@ TYPE = 'token'
 CONF = {'spaces': (int, 'consistent'),
         'indent-sequences': (bool, 'whatever', 'consistent'),
         'check-multi-line-strings': bool}
+DEFAULT = {'spaces': 'consistent',
+           'indent-sequences': True,
+           'check-multi-line-strings': False}
 
 ROOT, B_MAP, F_MAP, B_SEQ, F_SEQ, B_ENT, KEY, VAL = range(8)
 labels = ('ROOT', 'B_MAP', 'F_MAP', 'B_SEQ', 'F_SEQ', 'B_ENT', 'KEY', 'VAL')
@@ -224,7 +236,7 @@ def check_scalar_indentation(conf, token, context):
 
     def compute_expected_indent(found_indent):
         def detect_indent(base_indent):
-            if type(context['spaces']) is not int:
+            if not isinstance(context['spaces'], int):
                 context['spaces'] = found_indent - base_indent
             return base_indent + context['spaces']
 
@@ -312,7 +324,7 @@ def _check(conf, token, prev, next, nextnext, context):
                      token.start_mark.line + 1 > context['cur_line'])
 
     def detect_indent(base_indent, next):
-        if type(context['spaces']) is not int:
+        if not isinstance(context['spaces'], int):
             context['spaces'] = next.start_mark.column - base_indent
         return base_indent + context['spaces']
 
